@@ -29,5 +29,5 @@
 #############################################################################
 
 loadWorkbook <- function(filename, create = FALSE) {
-	jTryCatch(new("workbook", filename = filename, create = create))
+	jTryCatch(new("workbook", filename = path.expand(filename), create = create))
 }
