@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010 Mirai Solutions GmbH
+# Copyright (C) 2010-2012 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 .onLoad <- function(libname, pkgname) {
 	# Print package information
 	pdesc <- packageDescription(pkgname)
-	cat(pdesc$Package, pdesc$Version, "by", pdesc$Maintainer, "\n", sep = " ")
-	cat(pdesc$URL, "\n")
+	packageStartupMessage(pdesc$Package, " ", pdesc$Version, " by ", pdesc$Maintainer)
+	packageStartupMessage(pdesc$URL)
 	
 	# Load Java dependencies (all jars inside the java subfolder)
 	.jpackage(name = pkgname, jars = "*")
@@ -38,4 +38,3 @@
 	# Perform general XLConnect settings - pass package description
 	XLConnectSettings(pdesc)
 }
-
